<?php

namespace ZPOS\API;

use WC_REST_Controller;
use WP_REST_Server;
use ZPOS\Admin\Tabs\Users;
use ZPOS\Plugin;
use ZPOS\Admin\Tabs\Users\UserSettings;
use const ZPOS\REST_NAMESPACE;

class UserAccounts extends WC_REST_Controller
{
	protected $namespace = REST_NAMESPACE;
	protected $rest_base = 'user-accounts';

	public function __construct()
	{
		do_action(__METHOD__, $this, $this->namespace, $this->rest_base);
	}

	public function register_routes()
	{
		do_action(__METHOD__, $this, $this->namespace, $this->rest_base);

		register_rest_route($this->namespace, '/' . $this->rest_base, [
			'methods' => WP_REST_Server::READABLE,
			'callback' => [$this, 'get_user_accounts'],
			'permission_callback' => [$this, 'permission_check'],
		]);
	}

	public function get_user_accounts()
	{
		$current_user_login = wp_get_current_user()->user_login;

		$users = Plugin::isActive('MultipleUsersPOS')
			? Users::getAllowedUsers()
			: $this->get_pos_free_users();

		$users = array_filter($users, function ($user) use ($current_user_login) {
			return $user && $current_user_login !== $user->user_login;
		});

		return array_values(
			array_map(function (\WP_User $user) {
				return [
					'name' => $user->display_name,
					'email' => $user->user_email,
					'roles' => $user->roles,
				];
			}, $users)
		);
	}

	private function get_pos_free_users()
	{
		return array_map(function ($user_login) {
			return get_user_by('login', $user_login);
		}, array_values(UserSettings::getUsers()));
	}

	public function permission_check()
	{
		return is_user_logged_in();
	}
}
