<?php

namespace ZPOS\Admin\Tabs;

use ZPOS\Admin\Setting\Box;
use ZPOS\Admin\Setting\PageTab;
use ZPOS\Admin\Setting\Input\ConnectionTypes;
use ZPOS\Deactivate;
use ZPOS\Plugin;
use ZPOS\Structure\ArrayObject;
use ZPOS_UI\License as UILicense;

class Connection extends PageTab
{
	public $exact = true;
	public $name;
	public $path = '/connection';

	public function __construct()
	{
		parent::__construct();

		$this->name = __('Connection', 'zpos-wp-api');
	}

	public function getBoxes()
	{
		$isPOSUIActive = Plugin::isActive('pos-ui');

		return [
			new Box(
				null,
				null,
				new ConnectionTypes(
					'',
					'pos_ui_connection',
					get_option('pos_ui_connection', 'cloud-hosted'),
					$this->get_connections_values($isPOSUIActive),
					['isPOSUIActive' => $isPOSUIActive]
				)
			),
		];
	}

	private function get_connections_values($isPOSUIActive)
	{
		$connections_values = [
			[
				'value' => 'cloud-hosted',
				'label' => __('Cloud Connection', 'zpos-wp-api'),
				'info' => [
					'Title' => __('Cloud', 'zpos-wp-api'),
					'TextDomain' => 'zpos-wp-api',
					'Description' => __('POS hosted on BizSwoop servers', 'zpos-wp-api'),
					'URI' => 'https://www.bizswoop.com/wp/pos/',
					'Installed' => false,
					'Status' => false,
					'HideStatus' => true,
					'PermalinkURI' => Plugin::getPOSCloudAppURL(),
					'Type' => 'cloud-hosted',
					'Connected' =>
						'cloud-hosted' === get_option('pos_ui_connection', 'cloud-hosted') ||
						($isPOSUIActive && !UILicense::isActive()) ||
						!$isPOSUIActive,
				],
			],
			[
				'value' => 'server-hosted',
				'label' => __('Self-Hosted Connection', 'zpos-wp-api'),
				'info' => [
					'Title' => __('Self-Hosted Server', 'zpos-wp-api'),
					'TextDomain' => 'zpos-wp-api',
					'Description' => __('POS hosted on your WordPress website server.', 'zpos-wp-api'),
					'URI' => 'https://www.bizswoop.com/pos/self-hosted',
					'Installed' => in_array('zpos-wp-ui', array_column(get_plugins(), 'TextDomain')),
					'Status' => $isPOSUIActive,
					'HideStatus' => true,
					'PermalinkURI' => home_url('pos'),
					'Type' => 'server-hosted',
					'Connected' =>
						'server-hosted' === get_option('pos_ui_connection', 'cloud-hosted') &&
						$isPOSUIActive &&
						UILicense::isActive(),
					'Enable' => ['type' => 'link', 'to' => admin_url('plugins.php')],
				],
			],
		];

		return (new ArrayObject($connections_values))
			->map(function ($plugin) {
				$lowerCaseInfo = array_combine(
					array_map('strtolower', array_keys($plugin['info'])),
					$plugin['info']
				);

				$plugin = array_merge($plugin, ['info' => $lowerCaseInfo]);

				return array_combine(array_map('strtolower', array_keys($plugin)), $plugin);
			})
			->get();
	}

	public function init()
	{
		register_setting('pos' . $this->path, 'pos_ui_connection', [
			'default' => 'cloud-hosted',
		]);
	}

	public static function reset()
	{
		if (!did_action(Deactivate::class . '::resetSettings')) {
			return _doing_it_wrong(
				__METHOD__,
				'Reset POS settings should called by ' . Deactivate::class . '::resetSettings',
				'2.0.3'
			);
		}

		delete_option('pos_ui_connection');
	}
}
