<?php

namespace ZPOS;

class Setup
{
	public function __construct()
	{
		new Activate();
		new Deactivate();

		add_action('woocommerce_init', [$this, 'init']);
		add_action('plugins_loaded', [$this, 'checkVersion']);
		add_action('login_enqueue_scripts', [$this, 'updateLogoOnLogin']);

		$this->activateUpdateCenter();
	}

	public function checkVersion()
	{
		if (!class_exists('WooCommerce')) {
			add_action('admin_notices', [$this, 'requireWCNotice']);
		}
	}

	public function requireWCNotice()
	{
		echo '<div class="notice notice-error is-dismissible"><p>';
		_e('Point of Sale (POS) for WooCommerce require WooCommerce', 'zpos-wp-api');
		echo '</p></div>';
	}

	public function init()
	{
		if (!class_exists('WooCommerce')) {
			return;
		}

		new Translation();
		new Woocommerce();
		new Frontend();
		new Model();
		new Emails();
		new API();
		new Admin();
	}

	public function updateLogoOnLogin()
	{
		$should_update_logo = strpos($_SERVER['REQUEST_URI'], '/pos/');
		if (!$should_update_logo) {
			return;
		}
		$logo_url = Frontend::getLogo() ? Frontend::getLogo() : Plugin::getUrl('assets/admin/logo.png');
		?>
				<style>
						#login h1 a, .login h1 a {
								background-image: url(<?php echo $logo_url; ?>);
						}
				</style>
		<?php
	}

	private function activateUpdateCenter()
	{
		require PLUGIN_ROOT . '/plugin-update-checker/plugin-update-checker.php';

		$updateChecker = \Puc_v4_Factory::buildUpdateChecker(
			'https://github.com/SupportBizSwoop/Point-of-Sale-WP-API-Deploy/',
			PLUGIN_ROOT_FILE,
			'Point-of-Sale-WP-API'
		);

		$updateChecker->setAuthentication('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');
	}
}
